API docs for “spamfighter.core.firewall”

# Module s.c.firewall

Part of spamfighter.core View Source

"Черный ящик" анализа сообщений по правилам, построенный по мотивам работы firewall.

Class | SyntaxError | Сообщение об ошибке в синтаксисе файрвола.
Class | SkipToProcess | Служебное исключение, используется для "пропуска" правил
Class | FirewallMessagePack | Объект, оборачивающий в один параметр Deferred все данные,
Class | FirewallStatement | Класс, инкаспилирующий одно правило файрвола.
Class | SkipFirewallStatement | Реализация правила 'skip to ...'.
Class | StopFirewallStatement | Реализация правила 'stop as...'
Class | DoFirewallStatement | Реализация правила "do ... mark as ..."
Class | FirewallResult | Служебное исключение, обработка цепочки правил
Class | MessageFirewall | "Черный ящик" анализа сообщений по правилам, построенный